@@ -1,7 +1,7 @@
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
- *  Copyright (C) 2007                    Moritz Grimm <gtgbr@gmx.net>
+ *  Copyright (C) 2007                    Moritz Grimm <mdgrimm@gmx.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -610,8 +610,11 @@ openResource(shout_t *shout, const char *fileName, int *popenFlag,
 		}
 		xfree(pCommandString);
 
-		if (qFlag)
+		if (qFlag) {
 			dup2(stderr_fd, fileno(stderr));
+			if (stderr_fd > 2)
+				close(stderr_fd);
+		}
 
 		return (filep);
 	}
